Request<T> class

Constructors

Request({required Uri url, required String method, required Map<String, String> headers, Stream<List<int>>? bodyBytes, bool followRedirects = true, int maxRedirects = 4, int? contentLength, FormData? files, bool persistentConnection = true, Decoder<T>? decoder, ResponseInterceptor<T>? responseInterceptor})
factory

Properties

bodyBytes → Stream<List<int>>
The BodyBytesStream of body from this Request
final
contentLength → int?
final
decoder → Decoder<T>?
final
files → FormData?
final
followRedirects → bool
When true, the client will follow redirects to resolves this Request
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Headers attach to this Request
final
maxRedirects → int
The maximum number of redirects if followRedirects is true.
final
method → String
The Http Method from this Request ex: GET,POST,PUT,DELETE
final
persistentConnection → bool
final
responseInterceptor → ResponseInterceptor<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
The Uri from request
final

Methods

copyWith({Uri? url, String? method, Map<String, String>? headers, Stream<List<int>>? bodyBytes, bool? followRedirects, int? maxRedirects, int? contentLength, FormData? files, bool? persistentConnection, Decoder<T>? decoder, bool appendHeader = true, ResponseInterceptor<T>? responseInterceptor}) → Request<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited