BaseWebSocket class

Constructors

BaseWebSocket(String url, {Duration ping = const Duration(seconds: 5), bool allowSelfSigned = true})

Properties

allowSelfSigned ↔ bool
getter/setter pair
connectionStatus ↔ ConnectionStatus?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed ↔ bool
getter/setter pair
ping ↔ Duration
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ WebSocket?
getter/setter pair
socketNotifier ↔ SocketNotifier?
getter/setter pair
url ↔ String
getter/setter pair

Methods

close([int? status, String? reason]) → void
connect() → Future
dispose() → void
emit(String event, dynamic data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, MessageSocket message) → void
onClose(CloseSocket fn) → void
onError(CloseSocket fn) → void
onMessage(MessageSocket fn) → void
onOpen(OpenSocket fn) → void
send(dynamic data) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited