RouteDecoder class

Constructors

RouteDecoder(List<GetPage> treeBranch, Map<String, String> parameters, Object? arguments)
const

Properties

arguments → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
parameters → Map<String, String>
final
route → GetPage?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeBranch → List<GetPage>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceArguments(Object? arguments) → void
replaceParameters(Object? arguments) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited