SnackbarController class

Constructors

SnackbarController(GetSnackBar snackbar)

Properties

future → Future<void>
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<GetSnackBarState>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snackbar → GetSnackBar
final

Methods

close({bool withAnimations = true}) → Future<void>
Close the snackbar with animation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → Future<void>
Adds GetSnackbar to a view queue. Only one GetSnackbar will be displayed at a time, and this method returns a future to when the snackbar disappears.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isSnackbarBeingShown → bool
no setter

Static Methods

cancelAllSnackbars() → void
closeCurrentSnackbar() → Future<void>