WidgetCache<T extends GetWidgetCache> class abstract

Annotations

Constructors

WidgetCache()

Properties

context → BuildContext?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T?
no setter

Methods

build(BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
onInit() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited