GetStringUtils extension

on

Properties

camelCase → String?

Available on String, provided by the GetStringUtils extension

converter the String
no setter
capitalize → String

Available on String, provided by the GetStringUtils extension

capitalize the String
no setter
capitalizeFirst → String

Available on String, provided by the GetStringUtils extension

Capitalize the first letter of the String
no setter
isAlphabetOnly → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is alphanumeric only
no setter
isAPKFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a APK File
no setter
isAudioFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a AudioFileName
no setter
isBinary → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a binary value
no setter
isBool → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a boolean
no setter
isCnpj → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a CNPJ number
no setter
isCpf → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a CPF number
no setter
isCurrency → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a currency
no setter
isDateTime → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a DateTime
no setter
isDocumentFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Document Word
no setter
isEmail → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Email
no setter
isExcelFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Document Excel
no setter
isHexadecimal → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Hexadecimal
no setter
isHTMLFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a HTML file
no setter
isImageFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a ImageFileName
no setter
isIPv4 → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a ipv4
no setter
isIPv6 → bool

Available on String, provided by the GetStringUtils extension

no setter
isMD5 → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a MD5 Hash
no setter
isNum → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a valid number
no setter
isNumericOnly → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is numeric only
no setter
isPalindrome → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a palindrome
no setter
isPassport → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a passport number
no setter
isPDFFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a PDF file
no setter
isPhoneNumber → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Phone Number
no setter
isPPTFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a Document Powerpoint
no setter
isSHA1 → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a SHA1 Hash
no setter
isSHA256 → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a SHA256 Hash
no setter
isTxtFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a TxtFileName
no setter
isURL → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a URL file
no setter
isVectorFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a vector
no setter
isVideoFileName → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a VideoFileName
no setter
paramCase → String?

Available on String, provided by the GetStringUtils extension

Discover if the String is a valid URL
no setter
removeAllWhitespace → String

Available on String, provided by the GetStringUtils extension

remove all whitespace from the String
no setter

Methods

capitalizeAllWordsFirstLetter() → String

Available on String, provided by the GetStringUtils extension

capitalize only first letter in String words to upper case
createPath([Iterable? segments]) → String

Available on String, provided by the GetStringUtils extension

add segments to the String
isCaseInsensitiveContains(String b) → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a case insensitive
isCaseInsensitiveContainsAny(String b) → bool

Available on String, provided by the GetStringUtils extension

Discover if the String is a case sensitive and contains any value
numericOnly({bool firstWordOnly = false}) → String

Available on String, provided by the GetStringUtils extension